@@ -49,11 +49,15 @@ from shellfish.fs import (
     chmod as chmod,
     copy_file as copy_file,
     cp as cp,
+    dir_exists as dir_exists,
+    dir_exists_async as dir_exists_async,
     dirpath_gen as dirpath_gen,
     dirs_gen as dirs_gen,
     exists as exists,
     exists_async as exists_async,
     extension as extension,
+    file_exists as file_exists,
+    file_exists_async as file_exists_async,
     file_lines_gen as file_lines_gen,
     filecmp as filecmp,
     filepath_gen as filepath_gen,
@@ -214,11 +218,15 @@ __all__ = (
     "chmod",
     "copy_file",
     "cp",
+    "dir_exists",
+    "dir_exists_async",
     "dirpath_gen",
     "dirs_gen",
     "exists",
     "exists_async",
     "extension",
+    "file_exists",
+    "file_exists_async",
     "file_lines_gen",
     "filecmp",
     "filepath_gen",
